==> james-project-3.7.5-source-release.zip: james-project/backends-common/rabbitmq/src/main/java/org/apache/james/backends/rabbitmq/RabbitMQServerVersion.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 * http://www.apache.org/licenses/LICENSE-2.0                   *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ***************************************************************/

package org.apache.james.backends.rabbitmq;

import java.util.Objects;

import com.fasterxml.jackson.core.Version;
import com.fasterxml.jackson.core.util.VersionUtil;
import com.google.common.annotations.VisibleForTesting;
import com.google.common.base.MoreObjects;

public class RabbitMQServerVersion {
    public static RabbitMQServerVersion of(String input) {
        return new RabbitMQServerVersion(VersionUtil.parseVersion(input, "rabbitmq", "version"));
    }

    private final Version version;

    @VisibleForTesting
    RabbitMQServerVersion(Version version) {
        this.version = version;
    }

    public boolean isAtLeast(RabbitMQServerVersion other) {
        return version.compareTo(other.version) >= 0;
    }

    public String asString() {
        return version.toFullString();
    }

    @Override
    public final boolean equals(Object other) {
        if (other instanceof RabbitMQServerVersion) {
            RabbitMQServerVersion that = (RabbitMQServerVersion) other;
            return Objects.equals(version, that.version);
        }

        return false;
    }

    @Override
    public final int hashCode() {
        return Objects.hash(version);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
            .add("version", version)
            .toString();
    }
}

==> james-project-3.9.0-source-release.zip: james-project/backends-common/rabbitmq/src/main/java/org/apache/james/backends/rabbitmq/RabbitMQServerVersion.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 * http://www.apache.org/licenses/LICENSE-2.0                   *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ***************************************************************/

package org.apache.james.backends.rabbitmq;

import java.util.Objects;

import com.fasterxml.jackson.core.Version;
import com.fasterxml.jackson.core.util.VersionUtil;
import com.google.common.annotations.VisibleForTesting;
import com.google.common.base.MoreObjects;
import com.google.common.base.Preconditions;

public class RabbitMQServerVersion {
    public static RabbitMQServerVersion of(String input) {
        return new RabbitMQServerVersion(VersionUtil.parseVersion(input, "rabbitmq", "version"));
    }

    private final Version version;

    @VisibleForTesting
    RabbitMQServerVersion(Version version) {
        Preconditions.checkNotNull(version, "version cannot be null");
        this.version = version;
    }

    public boolean isAtLeast(RabbitMQServerVersion other) {
        return version.compareTo(other.version) >= 0;
    }

    public String asString() {
        return version.toFullString();
    }

    @Override
    public final boolean equals(Object other) {
        if (other instanceof RabbitMQServerVersion that) {
            return Objects.equals(version.getMajorVersion(), that.version.getMajorVersion()) &&
                Objects.equals(version.getMinorVersion(), that.version.getMinorVersion()) &&
                Objects.equals(version.getPatchLevel(), that.version.getPatchLevel());
        }

        return false;
    }

    @Override
    public final int hashCode() {
        return Objects.hash(version);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
            .add("version", version)
            .toString();
    }
}
